@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -603,7 +603,7 @@ function check_right_on_trigger_by_expression($permission, $expression) {
 
 	$hosts = API::Host()->get([
 		'filter' => ['host' => $expressionHosts],
-		'editable' => ($permission == PERM_READ_WRITE) ? 1 : null,
+		'editable' => ($permission == PERM_READ_WRITE),
 		'output' => ['hostid', 'host'],
 		'templated_hosts' => true,
 		'preservekeys' => true
@@ -1175,9 +1175,9 @@ function make_trigger_details($trigger) {
 		]);
 	}
 
-	$table->addRow([_('Disabled'), (TRIGGER_STATUS_ENABLED == $trigger['status'])
-		? (new CCol(_('No')))->addClass(ZBX_STYLE_GREEN)
-		: (new CCol(_('Yes')))->addClass(ZBX_STYLE_RED)
+	$table->addRow([_('Enabled'), ($trigger['status'] == TRIGGER_STATUS_ENABLED)
+		? (new CCol(_('Yes')))->addClass(ZBX_STYLE_GREEN)
+		: (new CCol(_('No')))->addClass(ZBX_STYLE_RED)
 	]);
 
 	return $table;
